import 'package:cryptography/cryptography.dart';
import 'package:cryptography/src/_internal/hex.dart';
import 'package:test/expect.dart';

Future<void> testHash({
  bool cycles = false,
  required HashAlgorithm algorithm,
  required List<int> input,
  required List<int> expected,
}) async {
  if (cycles) {
    var hashBytes = <int>[];
    for (var i = 0; i < input.length; i++) {
      final hash = await algorithm.hash(input.sublist(0, i));
      hashBytes = hash.bytes;

      // XOR data with the hash.
      // Thus input for the next hash will be a function of the previous hash.
      for (var i = 0; i < input.length; i++) {
        input[i] ^= hashBytes[i % hashBytes.length];
      }
    }
    expect(
      hexFromBytes(hashBytes),
      hexFromBytes(expected),
    );
  } else {
    final actual = await algorithm.hash(input);
    expect(
      hexFromBytes(actual.bytes),
      hexFromBytes(expected),
    );
  }
}

Future<void> testMac({
  required MacAlgorithm algorithm,
  required List<int> key,
  required List<int> input,
  required List<int> expected,
}) async {
  final actual = await algorithm.calculateMac(
    input,
    secretKey: SecretKeyData(key),
  );
  expect(
    hexFromBytes(actual.bytes),
    hexFromBytes(expected),
  );
}
