import 'dart:typed_data';

import 'package:cryptography/cryptography.dart';
import 'package:cryptography/src/utils.dart';
import 'package:test/test.dart';

import '_generated.dart';

void main() {
  test('Sha256(); data = []', () async {
    await testHash(
      algorithm: Sha256(),
      input: hexToBytes(''),
      expected: hexToBytes(
        'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855',
      ),
    );
  });
  test('Sha256(); data = [0]', () async {
    await testHash(
      algorithm: Sha256(),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '6e340b9cffb37a989ca544e6bb780a2c78901d3fb33738768511a30617afa01d',
      ),
    );
  });
  test('Sha256(); data = [1]', () async {
    await testHash(
      algorithm: Sha256(),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '4bf5122f344554c53bde2ebb8cd2b7e3d1600ad631c385a5d7cce23c7785459a',
      ),
    );
  });
  test('Sha256(); data = 31 bytes', () async {
    await testHash(
      algorithm: Sha256(),
      input: Uint8List(31),
      expected: hexToBytes(
        'fd08be957bda07dc529ad8100df732f9ce12ae3e42bcda6acabe12c02dfd6989',
      ),
    );
  });
  test('Sha256(); data = 32 bytes', () async {
    await testHash(
      algorithm: Sha256(),
      input: Uint8List(32),
      expected: hexToBytes(
        '66687aadf862bd776c8fc18b8e9f8e20089714856ee233b3902a591d0d5f2925',
      ),
    );
  });
  test('Sha256(); data = 33 bytes', () async {
    await testHash(
      algorithm: Sha256(),
      input: Uint8List(33),
      expected: hexToBytes(
        '7f9c9e31ac8256ca2f258583df262dbc7d6f68f2a03043d5c99a4ae5a7396ce9',
      ),
    );
  });
  test('Hmac.sha256(); key = [1, 2, 3]; data = []', () async {
    await testMac(
      algorithm: Hmac.sha256(),
      key: hexToBytes('010203'),
      input: hexToBytes(''),
      expected: hexToBytes(
        '368ac05cd81d972174a46fd54daa74ed0e808c09b0cc86f0c3fc342bef66f405',
      ),
    );
  });
  test('Hmac.sha256(); key = [1, 2, 3]; data = [0]', () async {
    await testMac(
      algorithm: Hmac.sha256(),
      key: hexToBytes('010203'),
      input: hexToBytes('00'),
      expected: hexToBytes(
        'd5b05509ef3c0e93562fdc5673a27c66215e0a71b1b826f6bb5023ed05d8c9f8',
      ),
    );
  });
  test('Hmac.sha256(); key = [1, 1, 1]; data = [1]', () async {
    await testMac(
      algorithm: Hmac.sha256(),
      key: hexToBytes('010101'),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '26be3b67bdceaac32854d31ce77932a277390565b448da817a223ed1d8b9e976',
      ),
    );
  });
  test('Hmac.sha256(); key = 31 bytes; data = 31 bytes', () async {
    await testMac(
      algorithm: Hmac.sha256(),
      key: Uint8List(31),
      input: Uint8List(31),
      expected: hexToBytes(
        'bd28265d692a7b5429233c5ae553468766c9d4c37614cce97ac73639e59a0728',
      ),
    );
  });
  test('Hmac.sha256(); key = 32 bytes; data = 32 bytes', () async {
    await testMac(
      algorithm: Hmac.sha256(),
      key: Uint8List(32),
      input: Uint8List(32),
      expected: hexToBytes(
        '33ad0a1c607ec03b09e6cd9893680ce210adf300aa1f2660e1b22e10f170f92a',
      ),
    );
  });
  test('Hmac.sha256(); key = 33 bytes; data = 33 bytes', () async {
    await testMac(
      algorithm: Hmac.sha256(),
      key: Uint8List(33),
      input: Uint8List(33),
      expected: hexToBytes(
        'd96ffd8e5141b5f4a50647daaa24d24c4670db24fa58838b299aa8158340835d',
      ),
    );
  });
  test('Sha384(); data = []', () async {
    await testHash(
      algorithm: Sha384(),
      input: hexToBytes(''),
      expected: hexToBytes(
        '38b060a751ac96384cd9327eb1b1e36a21fdb71114be07434c0cc7bf63f6e1da274edebfe76f65fbd51ad2f14898b95b',
      ),
    );
  });
  test('Sha384(); data = [0]', () async {
    await testHash(
      algorithm: Sha384(),
      input: hexToBytes('00'),
      expected: hexToBytes(
        'bec021b4f368e3069134e012c2b4307083d3a9bdd206e24e5f0d86e13d6636655933ec2b413465966817a9c208a11717',
      ),
    );
  });
  test('Sha384(); data = [1]', () async {
    await testHash(
      algorithm: Sha384(),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '8d2ce87d86f55fcfab770a047b090da23270fa206832dfea7e0c946fff451f819add242374be551b0d6318ed6c7d41d8',
      ),
    );
  });
  test('Sha384(); data = 63 bytes', () async {
    await testHash(
      algorithm: Sha384(),
      input: Uint8List(63),
      expected: hexToBytes(
        'c008e9ee239dc1c1cfd8fbffe726769b5b4b0c3424c15137ba987fde29b70dc9363733fbcffd14c8decffd6326638ee7',
      ),
    );
  });
  test('Sha384(); data = 64 bytes', () async {
    await testHash(
      algorithm: Sha384(),
      input: Uint8List(64),
      expected: hexToBytes(
        'c516aa8d3b457c636c6826937099c0d23a13f2c3701a388b3c8fe4bc2073281b0c4462610369884c4ababa8e97b6debe',
      ),
    );
  });
  test('Sha384(); data = 47 bytes', () async {
    await testHash(
      algorithm: Sha384(),
      input: Uint8List(47),
      expected: hexToBytes(
        'b0e809d91e9ee7d3c9fe9b107bcfebc205719ede210fd3afc4e9f5929080979d6e93c9edcbebee1d1087f06a8eb095c8',
      ),
    );
  });
  test('Sha384(); data = 48 bytes', () async {
    await testHash(
      algorithm: Sha384(),
      input: Uint8List(48),
      expected: hexToBytes(
        '8f0d145c0368ad6b70be22e41c400eea91b971d96ba220fec9fae25a58dffdaaf72dbe8f6783d55128c9df4efaf6f8a7',
      ),
    );
  });
  test('Sha384(); data = 49 bytes', () async {
    await testHash(
      algorithm: Sha384(),
      input: Uint8List(49),
      expected: hexToBytes(
        'bbed42a5f3fb8e40e65aaf7759fe54b4021f70f09bbb80d6f8cb06aea4205b378942f934c1e503ce091d61166faefb75',
      ),
    );
  });
  test('Sha384(); data = 63 bytes', () async {
    await testHash(
      algorithm: Sha384(),
      input: Uint8List(63),
      expected: hexToBytes(
        'c008e9ee239dc1c1cfd8fbffe726769b5b4b0c3424c15137ba987fde29b70dc9363733fbcffd14c8decffd6326638ee7',
      ),
    );
  });
  test('Sha384(); data = 64 bytes', () async {
    await testHash(
      algorithm: Sha384(),
      input: Uint8List(64),
      expected: hexToBytes(
        'c516aa8d3b457c636c6826937099c0d23a13f2c3701a388b3c8fe4bc2073281b0c4462610369884c4ababa8e97b6debe',
      ),
    );
  });
  test('Sha384(); data = 65 bytes', () async {
    await testHash(
      algorithm: Sha384(),
      input: Uint8List(65),
      expected: hexToBytes(
        'a53e5394c9adbbde8c06d18cb1f54f115832948b7fbed610791150c486677209eb6f69ed0f9a3151dbfa1b957e35a2fc',
      ),
    );
  });
  test('Hmac.sha384(); key = [1, 2, 3]; data = []', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: hexToBytes('010203'),
      input: hexToBytes(''),
      expected: hexToBytes(
        '9f131372c0ae781882c2cef778454182ebcf9a76702119ed1055ee30156567e4aa9e10f95372da802109470e9e61f04e',
      ),
    );
  });
  test('Hmac.sha384(); key = [1, 2, 3]; data = [0]', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: hexToBytes('010203'),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '1f1af2645ad672e41a5ac3fdb5508320e36581df13abfad42d950f98c1437222835aee1a8ce98d7ef98474a6e7d73981',
      ),
    );
  });
  test('Hmac.sha384(); key = [1, 1, 1]; data = [0]', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: hexToBytes('010101'),
      input: hexToBytes('00'),
      expected: hexToBytes(
        'c45ba9254179a517e3fa98410e019cae3fdf57309d7cad698e66290412aed5faeaf4e8629b463935fd2a03c95581f664',
      ),
    );
  });
  test('Hmac.sha384(); key = 47 bytes; data = 47 bytes', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: Uint8List(47),
      input: Uint8List(47),
      expected: hexToBytes(
        '41ee547aa7e9c4a7b21d1ef43b36f7224ccda2bc30a575451bee78ea020339ff345dbff78e02b88f4775e7f101ad7233',
      ),
    );
  });
  test('Hmac.sha384(); key = 48 bytes; data = 48 bytes', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: Uint8List(48),
      input: Uint8List(48),
      expected: hexToBytes(
        '7ee8206f5570023e6dc7519eb1073bc4e791ad37b5c382aa10ba18e2357e716971f9362f2c2fe2a76bfd78dfec4ea9b5',
      ),
    );
  });
  test('Hmac.sha384(); key = 49 bytes; data = 49 bytes', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: Uint8List(49),
      input: Uint8List(49),
      expected: hexToBytes(
        '0ae640af1a06346fab0318e5bf963a7e394de6068449dd6f0b0567eac71ea140c6006d73187942af22591666ac5d3c9d',
      ),
    );
  });
  test('Hmac.sha384(); key = 63 bytes; data = 63 bytes', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: Uint8List(63),
      input: Uint8List(63),
      expected: hexToBytes(
        '5fb1cd89424095af70b14f8f113111b43d15d1de8a75fcc17491c13acd9999867836e1afb1e9d7bafad66599dc931f38',
      ),
    );
  });
  test('Hmac.sha384(); key = 64 bytes; data = 64 bytes', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: Uint8List(64),
      input: Uint8List(64),
      expected: hexToBytes(
        'bfd97538f2dc27758d2d9797d9fabfc2d6ab4fc5dab3ab427f079639e36368e601dff0650f9487d672e08ba9e43f8f87',
      ),
    );
  });
  test('Hmac.sha384(); key = 65 bytes; data = 65 bytes', () async {
    await testMac(
      algorithm: Hmac.sha384(),
      key: Uint8List(65),
      input: Uint8List(65),
      expected: hexToBytes(
        '1581be4e01d3cbaa1ef3fa69a20dbbd9f87d43ab806f3f11cb46ee051b2e417940871da7657ff40ee60ee511140068f1',
      ),
    );
  });
  test('Sha512(); data = []', () async {
    await testHash(
      algorithm: Sha512(),
      input: hexToBytes(''),
      expected: hexToBytes(
        'cf83e1357eefb8bdf1542850d66d8007d620e4050b5715dc83f4a921d36ce9ce47d0d13c5d85f2b0ff8318d2877eec2f63b931bd47417a81a538327af927da3e',
      ),
    );
  });
  test('Sha512(); data = [0]', () async {
    await testHash(
      algorithm: Sha512(),
      input: hexToBytes('00'),
      expected: hexToBytes(
        'b8244d028981d693af7b456af8efa4cad63d282e19ff14942c246e50d9351d22704a802a71c3580b6370de4ceb293c324a8423342557d4e5c38438f0e36910ee',
      ),
    );
  });
  test('Sha512(); data = [1]', () async {
    await testHash(
      algorithm: Sha512(),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '7b54b66836c1fbdd13d2441d9e1434dc62ca677fb68f5fe66a464baadecdbd00576f8d6b5ac3bcc80844b7d50b1cc6603444bbe7cfcf8fc0aa1ee3c636d9e339',
      ),
    );
  });
  test('Sha512(); data = 63 bytes', () async {
    await testHash(
      algorithm: Sha512(),
      input: Uint8List(63),
      expected: hexToBytes(
        'a405dec5087e201200212d9b99c62298c3b126681b5d607f39e9356bcfbf5fe618c53d5c31d31903d5a1d76f7ef8225d8c6dca92df040c6cc7ca3393f25131dc',
      ),
    );
  });
  test('Sha512(); data = 64 bytes', () async {
    await testHash(
      algorithm: Sha512(),
      input: Uint8List(64),
      expected: hexToBytes(
        '7be9fda48f4179e611c698a73cff09faf72869431efee6eaad14de0cb44bbf66503f752b7a8eb17083355f3ce6eb7d2806f236b25af96a24e22b887405c20081',
      ),
    );
  });
  test('Sha512(); data = 65 bytes', () async {
    await testHash(
      algorithm: Sha512(),
      input: Uint8List(65),
      expected: hexToBytes(
        '19dc6ae12de08b21b36c1ec7f353ce9e7cef73fa4d1354c436234167f0847bc9e2b85e2f36208f773ef324e2d79e6af1beca4470e44b8672b47d077efe33a1f8',
      ),
    );
  });
  test('Hmac.sha512(); key = [1, 2, 3]; data = []', () async {
    await testMac(
      algorithm: Hmac.sha512(),
      key: hexToBytes('010203'),
      input: hexToBytes(''),
      expected: hexToBytes(
        '50ec3193a42f7d1a2db0d2647f8f6c466a4b30256032a0df8f43f2c36c90bdf9991bb415857d1e1ce35aebe4d2fe4f5400ac0debb5c3bd25e3d0f81320c6c1a2',
      ),
    );
  });
  test('Hmac.sha512(); key = [1, 2, 3]; data = [0]', () async {
    await testMac(
      algorithm: Hmac.sha512(),
      key: hexToBytes('010203'),
      input: hexToBytes('00'),
      expected: hexToBytes(
        'e6c49b846a1ec4270a399f9d5afd68e1148c423498dbd4a69b15d98821e88a93c2242413c766dee1a029290ad7f2b04d72c97d8b5db31f4f2bf4117dfe660b9c',
      ),
    );
  });
  test('Hmac.sha512(); key = [1, 1, 1]; data = [0]', () async {
    await testMac(
      algorithm: Hmac.sha512(),
      key: hexToBytes('010101'),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '4ef63c823d7a7971c4c0d20a38c043039963c6389f9de333ae3485833880f41e3474906268521ab6bdb6092054ce8441eb5af88be86f94edd26f71d4d9a25728',
      ),
    );
  });
  test('Hmac.sha512(); key = 63 bytes; data = 63 bytes', () async {
    await testMac(
      algorithm: Hmac.sha512(),
      key: Uint8List(63),
      input: Uint8List(63),
      expected: hexToBytes(
        '3d8d66780ed72ce87e66470d8a684ca18f1b40b7ae6b91f29b030d60f14ad05424108f8d3214c0e2629a60c51bd82412d099e0fff842673273ec817c23d7a261',
      ),
    );
  });
  test('Hmac.sha512(); key = 64 bytes; data = 64 bytes', () async {
    await testMac(
      algorithm: Hmac.sha512(),
      key: Uint8List(64),
      input: Uint8List(64),
      expected: hexToBytes(
        'fd4a40cb6252b3c08d9b88d5bde8533903caa51a1dba1c79ce18eea0365d35d071e597a2b95214821100e812f7b79828498f164707cd63c6f7464973cfa22046',
      ),
    );
  });
  test('Hmac.sha512(); key = 65 bytes; data = 65 bytes', () async {
    await testMac(
      algorithm: Hmac.sha512(),
      key: Uint8List(65),
      input: Uint8List(65),
      expected: hexToBytes(
        'ffe4f05234f0158c719d47501b2b06503c06e548545c0fd613b5a5607af615f9da9311ac87109b2fc1677329bf4f714271e5023ea49f74d1466b200236e82377',
      ),
    );
  });
  test('Blake2b(); data = []', () async {
    await testHash(
      algorithm: Blake2b(),
      input: hexToBytes(''),
      expected: hexToBytes(
        '786a02f742015903c6c6fd852552d272912f4740e15847618a86e217f71f5419d25e1031afee585313896444934eb04b903a685b1448b755d56f701afe9be2ce',
      ),
    );
  });
  test('Blake2b(); data = [0]', () async {
    await testHash(
      algorithm: Blake2b(),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '2fa3f686df876995167e7c2e5d74c4c7b6e48f8068fe0e44208344d480f7904c36963e44115fe3eb2a3ac8694c28bcb4f5a0f3276f2e79487d8219057a506e4b',
      ),
    );
  });
  test('Blake2b(); data = [1]', () async {
    await testHash(
      algorithm: Blake2b(),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '9545ba37b230d8a2e716c4707586542780815b7c4088edcb9af6a9452d50f32474d5ba9aab52a67aca864ef2696981c2eadf49020416136afd838fb048d21653',
      ),
    );
  });
  test('Blake2b(); data = 127 bytes', () async {
    await testHash(
      algorithm: Blake2b(),
      input: Uint8List(127),
      expected: hexToBytes(
        '93cac6a4bedd751e1c145f8e76fec88fec246675898475585603bd228f883bcf4ebcc68ead8fa5f27890a243fa938bd7323ad41f9f06048a732cce2070b212c3',
      ),
    );
  });
  test('Blake2b(); data = 128 bytes', () async {
    await testHash(
      algorithm: Blake2b(),
      input: Uint8List(128),
      expected: hexToBytes(
        '865939e120e6805438478841afb739ae4250cf372653078a065cdcfffca4caf798e6d462b65d658fc165782640eded70963449ae1500fb0f24981d7727e22c41',
      ),
    );
  });
  test('Blake2b(); data = 129 bytes', () async {
    await testHash(
      algorithm: Blake2b(),
      input: Uint8List(129),
      expected: hexToBytes(
        'a60edba343e7a6933c14d203d2e535f35e6deb6c8a4f8e624c1a6f6e2612860447cb4c37e5aa11bcf03b7c3eea7228eb8b998f922794f2d1b8f2dc63f03bd3fa',
      ),
    );
  });
  test('Blake2b(); 1000 cycles', () async {
    await testHash(
      algorithm: Blake2b(),
      cycles: true,
      input: Uint8List(1000),
      expected: hexToBytes(
        '1efabbf7cae9378f8f6657958dc7647eb4705b2088e819df04a46f5ce86419c754c7187888ac9cb5633e7277e256e92a944e5215cbfea5d0f981a554bc7a9472',
      ),
    );
  });
  test('Blake2b(); key = 32 bytes; data = []', () async {
    await testMac(
      algorithm: Blake2b(),
      key: Uint8List(32),
      input: hexToBytes(''),
      expected: hexToBytes(
        'cc789030610fd4bb91f53cf66fe84fa8670c76680e77a45aa32371a71901b9f3d954c08a3f96dec2f4485e005fb74b1bcdd54bbfff0581a611b15fb93702b347',
      ),
    );
  });
  test('Blake2b(); key = 64 bytes; data = [0]', () async {
    await testMac(
      algorithm: Blake2b(),
      key: Uint8List(64),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '5c583bdc55b5a5c1c973904b9e853babfdc72c6a4b95c3b47467b9a7bce9100d5e583b62fb319537a285197ea00af6cfb7d3634d2e114b8647e5f72a8f20ff4b',
      ),
    );
  });
  test('Blake2b(); key = 64 bytes; data = [1]', () async {
    await testMac(
      algorithm: Blake2b(),
      key: Uint8List(64),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '6e25dd2880f298190d847f8f1b970733b32677d9ca00ca2b37bf0d552b6d4f0eac25d6b746471d503ee9ee4701cacbed9e860cf793f7d0a36d62d93cd5afa8f3',
      ),
    );
  });
  test('Blake2b(); key = [1, 2, 3]; data = [0]', () async {
    await testMac(
      algorithm: Blake2b(),
      key: hexToBytes('010203'),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '6f8fbdd7939b3810abf851d6cf648080bac7b6668e09b370ece4faf7dd44c90a1c03f13157dfc3064f272bd678fbc7ef6d9e2be51545ce3be6810f036ce0b16a',
      ),
    );
  });
  test('Blake2b(); key = [1, 2, 3]; data = [1]', () async {
    await testMac(
      algorithm: Blake2b(),
      key: hexToBytes('010203'),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '468c7200537ba151a58fa07e78de0999d8927e2fc37e2f8e8075d191e2888919b98d98d2be4e159a1f92175a1cfdc4bf7c01fa813608513c70339a8411b365a5',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); data = []', () async {
    await testHash(
      algorithm: Blake2b(hashLengthInBytes: 32),
      input: hexToBytes(''),
      expected: hexToBytes(
        '0e5751c026e543b2e8ab2eb06099daa1d1e5df47778f7787faab45cdf12fe3a8',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); data = [0]', () async {
    await testHash(
      algorithm: Blake2b(hashLengthInBytes: 32),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '03170a2e7597b7b7e3d84c05391d139a62b157e78786d8c082f29dcf4c111314',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); data = [1]', () async {
    await testHash(
      algorithm: Blake2b(hashLengthInBytes: 32),
      input: hexToBytes('01'),
      expected: hexToBytes(
        'ee155ace9c40292074cb6aff8c9ccdd273c81648ff1149ef36bcea6ebb8a3e25',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); data = 127 bytes', () async {
    await testHash(
      algorithm: Blake2b(hashLengthInBytes: 32),
      input: Uint8List(127),
      expected: hexToBytes(
        '0f2dfeb03485c703d0c8584a40d135192ecb150247e9377595ed718d84b08a85',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); data = 128 bytes', () async {
    await testHash(
      algorithm: Blake2b(hashLengthInBytes: 32),
      input: Uint8List(128),
      expected: hexToBytes(
        '378d0caaaa3855f1b38693c1d6ef004fd118691c95c959d4efa950d6d6fcf7c1',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); data = 129 bytes', () async {
    await testHash(
      algorithm: Blake2b(hashLengthInBytes: 32),
      input: Uint8List(129),
      expected: hexToBytes(
        'baadfb64c3bd2cd187b54accc5e61a0720ed86bf48c28017873536cf9015d1b8',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); 1000 cycles', () async {
    await testHash(
      algorithm: Blake2b(hashLengthInBytes: 32),
      cycles: true,
      input: Uint8List(1000),
      expected: hexToBytes(
        'ac124145ca01fecee053afdea0bc7ab09869b45971c39ff34c19d044a4277b9b',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); key = [1, 2, 3]; data = []', () async {
    await testMac(
      algorithm: Blake2b(hashLengthInBytes: 32),
      key: hexToBytes('010203'),
      input: hexToBytes(''),
      expected: hexToBytes(
        '965e548eca2309ac7780325875f4531ce84f828968c38cdff527c809fcbe8e21',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); key = [1, 2, 3]; data = [0]', () async {
    await testMac(
      algorithm: Blake2b(hashLengthInBytes: 32),
      key: hexToBytes('010203'),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '02b8cc6d4451072fceb362457ee4b50ad8270c1fc161924bdc98da027cb2fa54',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); key = [1, 2, 3]; data = [1]', () async {
    await testMac(
      algorithm: Blake2b(hashLengthInBytes: 32),
      key: hexToBytes('010203'),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '08316816b9a028be83b364701921e9e59f9f420ebd4eadd5fbbd63fce2cff13d',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); key = 32 bytes; data = [0]', () async {
    await testMac(
      algorithm: Blake2b(hashLengthInBytes: 32),
      key: Uint8List(32),
      input: hexToBytes('00'),
      expected: hexToBytes(
        'f3719b9e9fbe04e35f255cd7a929c524d98db121192f646e52c33b9b1bd86d6f',
      ),
    );
  });
  test('Blake2b(hashLengthInBytes: 32); key = 32 bytes; data = [1]', () async {
    await testMac(
      algorithm: Blake2b(hashLengthInBytes: 32),
      key: Uint8List(32),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '6dda155f1a1224f7244044aadcc63ab601a2218a4f94e4d74873661b9a1ed8a9',
      ),
    );
  });
  test('Blake2s(); data = []', () async {
    await testHash(
      algorithm: Blake2s(),
      input: hexToBytes(''),
      expected: hexToBytes(
        '69217a3079908094e11121d042354a7c1f55b6482ca1a51e1b250dfd1ed0eef9',
      ),
    );
  });
  test('Blake2s(); data = [0]', () async {
    await testHash(
      algorithm: Blake2s(),
      input: hexToBytes('00'),
      expected: hexToBytes(
        'e34d74dbaf4ff4c6abd871cc220451d2ea2648846c7757fbaac82fe51ad64bea',
      ),
    );
  });
  test('Blake2s(); data = [1]', () async {
    await testHash(
      algorithm: Blake2s(),
      input: hexToBytes('01'),
      expected: hexToBytes(
        'fc87f4f1d721942d282aa61989c069b290d1447d20d4b811430f47ea0edf9991',
      ),
    );
  });
  test('Blake2s(); data = 63 bytes', () async {
    await testHash(
      algorithm: Blake2s(),
      input: Uint8List(63),
      expected: hexToBytes(
        'd962856f3fcfaac80a84722012c38da68cce6b924a397d5a3db009babefdee61',
      ),
    );
  });
  test('Blake2s(); data = 64 bytes', () async {
    await testHash(
      algorithm: Blake2s(),
      input: Uint8List(64),
      expected: hexToBytes(
        'ae09db7cd54f42b490ef09b6bc541af688e4959bb8c53f359a6f56e38ab454a3',
      ),
    );
  });
  test('Blake2s(); data = 65 bytes', () async {
    await testHash(
      algorithm: Blake2s(),
      input: Uint8List(65),
      expected: hexToBytes(
        '857328bf990b00922782d3e81c6054c25d3375d386c7424abe3e01d79041046c',
      ),
    );
  });
  test('Blake2s(); 1000 cycles', () async {
    await testHash(
      algorithm: Blake2s(),
      cycles: true,
      input: Uint8List(1000),
      expected: hexToBytes(
        'a2fd2eb37d3c9bb4cb811b1517573d67351d5976fe0b1c21956859df02e8df94',
      ),
    );
  });
  test('Blake2s(); key = [1, 2, 3]; data = []', () async {
    await testMac(
      algorithm: Blake2s(),
      key: hexToBytes('010203'),
      input: hexToBytes(''),
      expected: hexToBytes(
        '01f139bbb0a92cf39b8ce22420a898886a7a7e8e40d68ff42d3c12c05991ddf8',
      ),
    );
  });
  test('Blake2s(); key = [1, 2, 3]; data = [0]', () async {
    await testMac(
      algorithm: Blake2s(),
      key: hexToBytes('010203'),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '172454c9549a37a000ffdd1842e1de03754415627a064f07bf4bcb43d14b31e8',
      ),
    );
  });
  test('Blake2s(); key = [1, 2, 3]; data = [1]', () async {
    await testMac(
      algorithm: Blake2s(),
      key: hexToBytes('010203'),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '58f332a9894465b2e4fafa94b6db88e3cb632b72f30bf6395cb5326749e87cd4',
      ),
    );
  });
  test('Blake2s(); key = 32 bytes; data = [0]', () async {
    await testMac(
      algorithm: Blake2s(),
      key: Uint8List(32),
      input: hexToBytes('00'),
      expected: hexToBytes(
        '90e2e185abe1f18d54b302600db2f755081560074accf7f2b292b443085b4c10',
      ),
    );
  });
  test('Blake2s(); key = 32 bytes; data = [1]', () async {
    await testMac(
      algorithm: Blake2s(),
      key: Uint8List(32),
      input: hexToBytes('01'),
      expected: hexToBytes(
        '5e8a14c5ddf0baf8316f2c95085130bdc814b197c28c78e709bafe0c3f4d7d0b',
      ),
    );
  });
}